Struct VmlinuxBtfDump

pub struct VmlinuxBtfDump { /* private fields */ }
Load vmlinux from file and generate vmlinux.h

Implementations

Source

impl VmlinuxBtfDump

pub fn with_system_default() -> Result<Self, TypeGenError>

Probe few well-known locations for vmlinux kernel image and try to load BTF data out of it

pub fn with_elf_file(elf_file: impl AsRef<Path>) -> Result<Self, TypeGenError>

Read the ELF file and parse BTF data out of the given ELF file

pub fn with_raw_file(raw: impl AsRef<Path>) -> Result<Self, TypeGenError>

Parse BTF data from a file containing raw BTF data

pub fn allowlist(self, pattern: &str) -> Self

Add regex pattern into allowlist of BTF types

pub fn generate(self, outfile: impl AsRef<Path>) -> Result<(), TypeGenError>

Dump BTF types as C source code into outfile including all the necessary dependent types.